@@ -48,7 +48,7 @@ OC.L10N.register(
     "There was an error while setting up your account" : "Der opstod en fejl under opsætning af din konto",
     "Auto" : "Auto",
     "Name" : "Navn",
-    "Mail address" : "Mail addresse",
+    "Mail address" : "Mail adresse",
     "name@example.org" : "name@example.org",
     "Please enter an email of the format name@example.com" : "Indtast venligst en e-mail med formatet navn@eksempel.com",
     "Password" : "Kodeord",
@@ -159,13 +159,14 @@ OC.L10N.register(
     "Custom date and time" : "Brugerdefineret dato og tid",
     "Enter a date" : "Indtast en dato",
     "Choose" : "Vælg",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Den vedhæftede fil overskrider den tilladte størrelse på vedhæftede filer på {size}. Del venligst filen via link i stedet.","De vedhæftede filer overskrider den tilladte størrelse på vedhæftede filer på {size}. Del venligst filerne via link i stedet."],
     "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
     "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
     "_{count} attachment_::_{count} attachments_" : ["{count} vedhæftet fil","{count} vedhæftede filer"],
     "Confirm" : "Bekræft",
     "Plain text" : "Klartekst",
     "Rich text" : "Formateret tekst",
-    "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
+    "No messages in this folder" : "Ingen beskeder i denne mappe",
     "No messages" : "Ingen beskeder",
     "Blind copy recipients only" : "Kun blinde kopi-modtagere",
     "No subject" : "Intet emne",
@@ -173,9 +174,7 @@ OC.L10N.register(
     "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
     "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
     "Set reminder for next week" : "Sæt påmindelse for næste weekend",
-    "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
     "Could not delete message" : "Kunne ikke slette beskeden",
-    "Draft: " : "Kladde:",
     "This message is unread" : "Denne besked er ulæst",
     "Unfavorite" : "U-favorit",
     "Favorite" : "Favorit",
@@ -187,6 +186,7 @@ OC.L10N.register(
     "Edit tags" : "Rediger mærker",
     "Move thread" : "Flyt tråden",
     "Delete thread" : "Slet tråd",
+    "Delete message" : "Slet besked",
     "More actions" : "Flere handlinger",
     "Back" : "Tilbage",
     "Edit as new message" : "Rediger som ny besked",
@@ -227,13 +227,10 @@ OC.L10N.register(
     "Decline" : "Afvis",
     "Tentatively accept" : "Accepter foreløbigt",
     "More options" : "Flere muligheder",
-    "This event is in the past." : "Denne begivenhed er i fortiden.",
     "Remove" : "Fjern",
     "email" : "e-mail",
-    "Could not open mailbox" : "Postkassen kunne ikke åbnes",
     "Loading messages …" : "Indlæser beskeder...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksering af dine beskeder. Dette kan tage lidt længere tid for større postkasser.",
-    "Choose target mailbox" : "Vælg målpostkasse",
+    "Choose target folder" : "Vælg destinationsmappe",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
     "Important info" : "Vigtig information",
@@ -246,34 +243,39 @@ OC.L10N.register(
     "View source" : "Vis kildekode",
     "Unnamed" : "Unavngiven",
     "Embedded message" : "Indlejret besked",
-    "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
-    "Import into calendar" : "Importere til kalender",
+    "Choose a folder to store the attachment in" : "Vælg den mappe, som vedhæftningen skal gemmes i",
+    "Import into calendar" : "Importér til kalender",
     "Download attachment" : "Hent vedhæftning",
     "Save to Files" : "Gem til filer",
     "Choose a folder to store the attachments in" : "Vælg den mappe, hvor vedhæftningerne skal gemmes i",
     "Save all to Files" : "Gem alle filer",
-    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
+    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte dit privatliv.",
     "Show images" : "Vis billeder",
+    "Always show images from {sender}" : "Altid vis billeder fra {sender}",
+    "Always show images from {domain}" : "Altid vis billeder fra {domain}",
+    "Quoted text" : "Citeret tekst",
     "Move" : "Flyt",
-    "Loading …" : "Indlæser…",
+    "Moving" : "Flytter",
+    "Moving thread" : "Flytter tråd",
+    "Moving message" : "Flytter besked",
     "Remove account" : "Fjern konto",
     "Remove {email}" : "Fjern {email}",
-    "Quota" : "Kvote",
-    "Show only subscribed mailboxes" : "Vis kun postkasser der abonneres på",
-    "Add mailbox" : "Tilføj postkasse",
+    "Add folder" : "Tilføj mappe",
+    "Folder name" : "Mappenavn",
     "Saving" : "Gemmer",
     "Move up" : "Flyt op",
     "Move down" : "Flyt ned",
-    "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
-    "Show all mailboxes" : "Vis alle postkasser",
+    "Show all folders" : "Vis alle mapper",
     "Collapse mailboxes" : "Skjul postkasser ",
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
+    "Loading …" : "Indlæser…",
     "Clear mailbox {name}" : "Ryd postkasse {name}",
-    "Clear mailbox" : "Ryd postkasse",
-    "Mark all as read" : "Marker alle som læst",
-    "Mark all messages of this mailbox as read" : "Marker alle beskeder i denne postkasse som læst",
-    "Add submailbox" : "Tilføj underpostkasse",
+    "Delete folder" : "Slet mappe",
+    "Mark all as read" : "Markér alle som læst",
+    "Mark all messages of this folder as read" : "Markér alle beskeder i denne mappe som læst",
+    "Add subfolder" : "Tilføj undermappe",
     "Rename" : "Omdøb",
+    "Move folder" : "Flyt mappe",
     "Clear cache" : "Ryd cache",
     "Subscribed" : "Abonneret",
     "Sync in background" : "Synkroniser i baggrunden",
@@ -281,12 +283,9 @@ OC.L10N.register(
     "New message" : "Ny besked",
     "Draft" : "Kladde",
     "Reply" : "Besvar",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
     "Error sending your message" : "Fejl ved afsendelse af din besked",
     "Retry" : "Prøv igen",
-    "Uploading attachments …" : "Uploader vedhæftninger",
-    "Sending …" : "Sender ...",
     "Warning sending your message" : "Advarsel om at sende din besked",
     "Send anyway" : "Send alligevel",
     "Welcome to {productName} Mail" : "Velkommen til {productName} mail",
@@ -297,8 +296,8 @@ OC.L10N.register(
     "New Contact" : "Ny kontakt",
     "Copy to clipboard" : "Kopier til udklipsholder",
     "Add" : "Tilføj",
+    "Show less" : "Vis mindre",
     "Clear" : "Ryd",
-    "Search in mailbox" : "Søg i postkasse",
     "Close" : "Luk",
     "Search parameters" : "Søgeparametre",
     "Body" : "Krop",
@@ -316,6 +315,7 @@ OC.L10N.register(
     "Custom" : "Brugerdefineret",
     "Signature …" : "Underskrift …",
     "Save signature" : "Gem underskrift",
+    "Message source" : "Beskedens kildekode",
     "Saving new tag name …" : "Gemmer nyt tag navn ...",
     "Tag already exists" : "Mærket eksisterer allerede",
     "Add tag" : "Tilføj Tag",
@@ -325,12 +325,12 @@ OC.L10N.register(
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME-signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
     "Reply all" : "Besvar alle",
     "Reply to sender only" : "Besvar kun afsender",
-    "Mark as unread" : "Marker som ulæst",
-    "Mark as read" : "Marker som læst",
-    "Delete message" : "Slet besked",
-    "Message source" : "Beskedens kildekode",
+    "Mark as unread" : "Markér som ulæst",
+    "Mark as read" : "Markér som læst",
     "Go to newest message" : "Gå til nyeste besked",
-    "Copy translated text" : "Kopier oversat tekst",
+    "Translate from" : "Oversæt fra",
+    "Translate to" : "Oversæt til",
+    "Copy translated text" : "Kopiér oversat tekst",
     "Untitled event" : "Unavngiven begivenhed",
     "(organizer)" : "(arrangør)",
     "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
@@ -338,17 +338,17 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
     "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
     "Train" : "Tog",
+    "Recipient" : "Modtager",
     "New filter" : "Nyt filter",
     "Operator" : "Operatør",
-    "New test" : "Nyeste test",
-    "Actions" : "Handlinger",
-    "New action" : "Ny handling",
+    "contains" : "indeholder",
+    "matches" : "er lig med",
     "Priority" : "Prioritet",
     "Reset" : "Nulstil",
-    "Client ID" : "Klient-ID",
-    "Client secret" : "Klient hemmelighed",
+    "Client ID" : "Klient ID",
+    "Client secret" : "Klienthemmelighed",
     "IMAP" : "IMAP",
-    "User" : "ruger",
+    "User" : "Bruger",
     "Host" : "Vært",
     "Port" : "Port",
     "SMTP" : "SMTP",
@@ -362,14 +362,14 @@ OC.L10N.register(
     "Valid until" : "Gyldig indtil",
     "Delete certificate" : "Slet certifikat",
     "No certificate imported yet" : "Intet certifikat importeret endnu",
-    "Import certificate" : "Importer certifikat",
+    "Import certificate" : "Importér certifikat",
     "Import S/MIME certificate" : "Importer S/MIME-certifikat",
     "PKCS #12 Certificate" : "PKCS #12 Certifikat",
     "PEM Certificate" : "PEM Certifikat",
     "Certificate" : "Certifikat",
     "Private key (optional)" : "Privat nøgle (valgfrit)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøgle er kun påkrævet, hvis du har til hensigt at sende signerede og krypterede e-mails ved hjælp af dette certifikat.",
-    "Submit" : "Tilføj",
+    "Submit" : "Send",
     "Account connected" : "Kontoen er tilknyttet",
     "Connect your mail account" : "Forbind din mail konto",
     "All" : "Alle",
@@ -393,10 +393,28 @@ OC.L10N.register(
     "Could not load the desired message" : "Den ønskede besked kunne ikke indlæses",
     "Could not load the message" : "Beskeden kunne ikke indlæses",
     "Error loading message" : "Fejl under indlæsning af besked",
-    "Forwarding to %s" : "Videre send til %s",
+    "Forwarding to %s" : "Videresender til %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
-    "Continue to %s" : "Videre til %s"
+    "Continue to %s" : "Videre til %s",
+    "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
+    "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
+    "Draft: " : "Kladde:",
+    "Could not open mailbox" : "Postkassen kunne ikke åbnes",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksering af dine beskeder. Dette kan tage lidt længere tid for større postkasser.",
+    "Choose target mailbox" : "Vælg målpostkasse",
+    "Show only subscribed mailboxes" : "Vis kun postkasser der abonneres på",
+    "Add mailbox" : "Tilføj postkasse",
+    "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
+    "Show all mailboxes" : "Vis alle postkasser",
+    "Clear mailbox" : "Ryd postkasse",
+    "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
+    "Add submailbox" : "Tilføj underpostkasse",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
+    "Search in mailbox" : "Søg i postkasse",
+    "New test" : "Nyeste test",
+    "Actions" : "Handlinger",
+    "New action" : "Ny handling"
 },
 "nplurals=2; plural=(n != 1);");
