@@ -6,6 +6,10 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Later" : "Después",
     "Mail" : "Correo",
+    "Connecting" : "Conectando",
+    "Save" : "Guardar",
+    "Connect" : "Conectar",
+    "Password required" : "Se requiere contraseña",
     "Name" : "Nombre",
     "Mail address" : "Dirección de correo",
     "Password" : "Contraseña",
@@ -20,18 +24,16 @@ OC.L10N.register(
     "SMTP Port" : "Puerto SMTP",
     "SMTP User" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
-    "Connecting" : "Conectando",
-    "Save" : "Guardar",
-    "Connect" : "Conectar",
-    "Password required" : "Se requiere contraseña",
     "Aliases" : "Aliases",
     "Signature" : "Firma",
     "Go back" : "Regresar",
     "Cancel" : "Cancelar",
+    "Accounts" : "Accounts",
     "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
     "Register" : "Registrar",
+    "About" : "Acerca",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -47,9 +49,10 @@ OC.L10N.register(
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
-    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Choose" : "Seleccionar",
+    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Confirm" : "Confirmar",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "Unfavorite" : "Quitar favorito",
     "Favorite" : "Hacer favorito",
     "Read" : "Leer",
@@ -68,35 +71,36 @@ OC.L10N.register(
     "Other" : "Otro",
     "Forward" : "Adelante",
     "Translate" : "Traducir",
+    "Unnamed" : "Sin nombre",
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
-    "Unnamed" : "Sin nombre",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Move" : "Mover",
-    "Quota" : "Cuota",
-    "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
+    "Folder name" : "Nombre de la carpeta",
+    "Saving" : "Guardando",
+    "Show all folders" : "Mostrar todas las carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
-    "Retry" : "Reintentar",
-    "Sending …" : "Enviando ...",
     "Reply" : "Responder",
+    "Retry" : "Reintentar",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
+    "Clear" : "Limpiar",
     "Date" : "Fecha",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
-    "Clear" : "Limpiar",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
+    "Recipient" : "Destinatario",
     "Operator" : "Operador",
-    "Actions" : "Acciones",
+    "matches" : "coincide",
     "Priority" : "Prioridad",
     "Reset" : "Restablecer",
     "Client ID" : "ID del cliente",
@@ -129,6 +133,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "Actions" : "Acciones"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
