@@ -98,7 +98,6 @@ OC.L10N.register(
     "Sieve script editor" : "Editor de scripts Sieve",
     "Mail server" : "Servidor de correo",
     "Sieve server" : "Servidor Sieve",
-    "Mailbox search" : "Búsqueda en el buzón de correo",
     "Update alias" : "Actualizar alias",
     "Rename alias" : "Renombrar alias",
     "Show update alias form" : "Mostrar formulario de actualización de alias",
@@ -146,7 +145,6 @@ OC.L10N.register(
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain!" : "¡Mailvelope se encuentra habilitado para el dominio actual!",
     "Looking for a way to encrypt your emails?" : "¿Buscas una forma de cifrar tus correos electrónicos?",
-    "Install Mailvelope browser extension by clicking here" : "Instala la extensión del navegador Mailvelope haciendo clic aquí",
     "Enable Mailvelope for the current domain" : "Habilita Mailvelope para el dominio actual",
     "Assistance features" : "Características de asistencia",
     "About" : "Acerca",
@@ -228,7 +226,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "La etiqueta se eliminará de todos los mensajes.",
     "Plain text" : "Texto plano",
     "Rich text" : "Texto enriquecido",
-    "No messages in this mailbox" : "No hay mensajes en este buzón de correo",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "No messages" : "Sin mensajes",
     "Blind copy recipients only" : "Solo destinatarios de copia oculta",
     "No subject" : "Sin asunto",
@@ -236,14 +234,12 @@ OC.L10N.register(
     "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
     "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
     "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
-    "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
     "Could not delete message" : "No se pudo eliminar el mensaje",
     "Could not archive message" : "No se pudo archivar el mensaje",
     "Thread was snoozed" : "El hilo ha sido pausado",
     "Could not snooze thread" : "No se ha podido pausar el hilo",
     "Thread was unsnoozed" : "El hilo fue reanudado",
     "Could not unsnooze thread" : "No se pudo reanudar el hilo",
-    "Draft: " : "Borrador:",
     "Encrypted message" : "Mensaje encriptado",
     "This message is unread" : "Este mensaje no ha sido leído",
     "Unfavorite" : "Quitar favorito",
@@ -293,7 +289,6 @@ OC.L10N.register(
     "Decline" : "Rechazar",
     "Tentatively accept" : "Aceptar tentativamente",
     "More options" : "Más opciones",
-    "This event is in the past." : "Este evento fue en el pasado.",
     "Could not remove internal address {sender}" : "No se pudo remover la dirección interna {sender}",
     "Could not add internal address {address}" : "No se pudo agregar la dirección interna {address}",
     "individual" : "individual",
@@ -303,12 +298,9 @@ OC.L10N.register(
     "Add internal address" : "Agregar dirección interna",
     "Add internal email or domain" : "Agregar dirección de correo interna o dominio",
     "Itinerary for {type} is not supported yet" : "El itinerario para {type} aún no es soportado",
-    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivado en las configuraciones de la cuenta",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivado y/o eliminar este mensaje de la carpeta actual",
-    "Could not open mailbox" : "No se pudo abrir el buzón",
     "Loading messages …" : "Cargando mensajes...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indizando tus mensajes. Esto puede tardar un poco para buzones grandes.",
-    "Choose target mailbox" : "Escoger buzón de destino",
+    "Choose target folder" : "Elegir carpeta destino",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
     "Follow up" : "Seguimiento",
     "Follow up info" : "Información de seguimiento",
@@ -325,21 +317,23 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Quoted text" : "Texto citado",
     "Move" : "Mover",
-    "Loading …" : "Cargando …",
     "Remove account" : "Eliminar cuenta",
-    "Quota" : "Cuota",
+    "Add folder" : "Agregar carpeta",
+    "Folder name" : "Nombre de la carpeta",
     "Saving" : "Guardando",
     "Move up" : "Mover arriba",
     "Move down" : "Mover abajo",
-    "Clear mailbox" : "Vaciar buzón",
+    "Show all folders" : "Mostrar todas las carpetas",
+    "Loading …" : "Cargando …",
+    "Delete folder" : "Eliminar carpeta",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
+    "Move folder" : "Mover carpeta",
     "Clear cache" : "Borrar el caché",
     "Subscribed" : "Suscrito",
     "New message" : "Mensaje nuevo",
     "Reply" : "Responder",
     "Retry" : "Reintentar",
-    "Sending …" : "Enviando ...",
     "First day" : "Primer día",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
@@ -354,13 +348,15 @@ OC.L10N.register(
     "Last 7 days" : "Últimos 7 días",
     "Custom" : "Personalizado",
     "Tag already exists" : "La etiqueta ya existe",
-    "Add tag" : "Agregar etiqueta",
+    "Add tag" : "Añadir etiqueta",
     "Not found" : "No encontrado",
     "Translate from" : "Traducir desde",
     "Untitled event" : "Evento sin título",
     "(organizer)" : "(organizador)",
+    "Recipient" : "Destinatario",
     "Operator" : "Operador",
-    "Actions" : "Acciones",
+    "contains" : "contiene",
+    "matches" : "coincide",
     "Priority" : "Prioridad",
     "Reset" : "Reiniciar",
     "Client ID" : "ID del cliente",
@@ -395,6 +391,17 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "Mailbox search" : "Búsqueda en el buzón de correo",
+    "Install Mailvelope browser extension by clicking here" : "Instala la extensión del navegador Mailvelope haciendo clic aquí",
+    "No messages in this mailbox" : "No hay mensajes en este buzón de correo",
+    "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
+    "Draft: " : "Borrador:",
+    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivado en las configuraciones de la cuenta",
+    "Could not open mailbox" : "No se pudo abrir el buzón",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indizando tus mensajes. Esto puede tardar un poco para buzones grandes.",
+    "Choose target mailbox" : "Escoger buzón de destino",
+    "Clear mailbox" : "Vaciar buzón",
+    "Actions" : "Acciones"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
