@@ -95,6 +95,7 @@ OC.L10N.register(
     "Trusted senders" : "Luotetut lähettäjät",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
     "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
+    "Install Mailvelope browser extension" : "Asenna Mailvelope-selainlaajennus",
     "About" : "Tietoja",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Compose new message" : "Uusi viesti",
@@ -155,6 +156,7 @@ OC.L10N.register(
     "Custom date and time" : "Omavalintainen päivä ja aika",
     "Enter a date" : "Kirjoita päiväys",
     "Choose" : "Valitse",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Liite ylittää sallitun enimmäiskoon {size}. Jaa tiedosto linkin kautta.","Liitteet ylittävät sallitun enimmäiskoon {size}. Jaa tiedostot linkin kautta."],
     "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
     "_{count} attachment_::_{count} attachments_" : ["{count} liite","{count} liitettä"],
@@ -164,7 +166,7 @@ OC.L10N.register(
     "Confirm" : "Vahvista",
     "Plain text" : "Raakateksti",
     "Rich text" : "Rikas teksti",
-    "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
+    "No messages in this folder" : "Tässä kansiossa ei ole viestejä",
     "No messages" : "Ei viestejä",
     "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
     "No subject" : "Ei aihetta",
@@ -178,7 +180,6 @@ OC.L10N.register(
     "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
     "Could not delete message" : "Ei voitu poistaa viestiä",
     "Could not archive message" : "Viestiä ei voitu arkistoida",
-    "Draft: " : "Luonnos: ",
     "Encrypted message" : "Salattu viesti",
     "This message is unread" : "Tämä viesti on lukematon",
     "Unfavorite" : "Poista suosikeista",
@@ -192,7 +193,9 @@ OC.L10N.register(
     "Snooze" : "Torkuta",
     "Move thread" : "Siirrä ketju",
     "Archive thread" : "Arkistoi ketju",
+    "Archive message" : "Arkistoi viesti",
     "Delete thread" : "Poista ketju",
+    "Delete message" : "Poista viesti",
     "More actions" : "Lisää toimintoja",
     "Back" : "Takaisin",
     "Set custom snooze" : "Aseta mukautettu torkutus",
@@ -228,14 +231,12 @@ OC.L10N.register(
     "Decline" : "Kieltäydy",
     "Tentatively accept" : "Alustavasti hyväksytty",
     "More options" : "Lisää valintoja",
-    "This event is in the past." : "Tämä tapahtuma on menneisyydessä.",
     "individual" : "yksittäinen",
     "domain" : "domaini",
     "Remove" : "Poista",
     "email" : "sähköposti",
-    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
     "Loading messages …" : "Ladataan viestejä …",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
+    "Choose target folder" : "Valitse kohdekansio",
     "Important info" : "Tärkeää tietoa",
     "Other" : "Muu",
     "The sender of this message has asked to be notified when you read this message." : "Tämän viestin lähettäjä on pyytänyt ilmoitusta, kun luet tämän viestin.",
@@ -271,34 +272,32 @@ OC.L10N.register(
     "Moving" : "Siirretään",
     "Moving thread" : "Siirretään ketjua",
     "Moving message" : "Siirretään viestiä",
-    "Loading …" : "Ladataan…",
-    "Not supported by the server" : "Ei tuettu palvelimen toimesta",
-    "{usage} of {limit} used" : "{usage}/{limit} käytetty",
     "Remove account" : "Poista tili",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
     "Remove {email}" : "Poista {email}",
-    "Quota" : "Kiintiö",
-    "Show only subscribed mailboxes" : "Näytä vain tilatut postilaatikot",
-    "Add mailbox" : "Lisää postilaatikko",
+    "Show only subscribed folders" : "Näytä vain tilatut kansiot",
+    "Add folder" : "Lisää kansio",
+    "Folder name" : "Kansion nimi",
     "Saving" : "Tallennetaan",
     "Move up" : "Siirrä ylös",
     "Move down" : "Siirrä alas",
-    "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
-    "Show all mailboxes" : "Näytä kaikki postilaatikot",
+    "Show all subscribed folders" : "Näytä kaikki tilatut kansiot",
+    "Show all folders" : "Näytä kaikki kansiot",
     "Collapse mailboxes" : "Supista postilaatikot",
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
+    "Loading …" : "Ladataan…",
     "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
     "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
-    "Clear mailbox" : "Tyhjennä postilaatikko",
-    "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
-    "Delete mailbox" : "Poista postilaatikko",
-    "Delete mailbox {name}" : "Poista postilaatikko {name}",
+    "The folder and all messages in it will be deleted." : "Tämä kansio ja kaikki sen viestit poistetaan.",
+    "Delete folder" : "Poista kansio",
+    "Delete folder {name}" : "Poista kansio {name}",
     "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
     "Mark all as read" : "Merkitse kaikki luetuiksi",
-    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
-    "Add submailbox" : "Lisää alipostilaatikko",
+    "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
+    "Add subfolder" : "Lisää alikansio",
     "Rename" : "Nimeä uudelleen",
+    "Move folder" : "Siirrä kansio",
     "Clear cache" : "Tyhjennä välimuisti",
     "Clear locally cached data, in case there are issues with synchronization." : "Poista paikallisesti tallennetut tiedot, jos synkronoinnissa on ongelmia.",
     "Subscribed" : "Tilattu",
@@ -310,14 +309,11 @@ OC.L10N.register(
     "Message saved" : "Viesti tallennettu",
     "Failed to save message" : "Viestin tallentaminen epäonnistui",
     "Failed to save draft" : "Luonnoksen tallentaminen epäonnistui",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
     "Message discarded" : "Viesti hylätty",
     "Could not discard message" : "Viestiä ei voitu hylätä",
     "Minimize composer" : "Pienennä lähetysikkuna",
     "Error sending your message" : "Virhe viestiäsi lähettäessä",
     "Retry" : "Yritä uudelleen",
-    "Uploading attachments …" : "Lähetetään liitteitä…",
-    "Sending …" : "Lähetetään…",
     "Warning sending your message" : "Varoitus viestiä lähettäessä",
     "Send anyway" : "Lähetä silti",
     "Autoresponder off" : "Automaattivastaukset pois päältä",
@@ -360,6 +356,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
+    "Message source" : "Viestin lähde",
     "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
     "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
     "Delete tag" : "Poista tunniste",
@@ -384,9 +381,6 @@ OC.L10N.register(
     "Mark as favorite" : "Merkitse suosikiksi",
     "Mark as unread" : "Merkitse lukemattomaksi",
     "Mark as read" : "Merkitse luetuksi",
-    "Archive message" : "Arkistoi viesti",
-    "Delete message" : "Poista viesti",
-    "Message source" : "Viestin lähde",
     "The message could not be translated" : "Viestiä ei voitu kääntää",
     "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
     "Translation could not be copied" : "Käännöstä ei voitu kopioida",
@@ -410,11 +404,12 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
     "Train" : "Juna",
     "Flag" : "Lippu",
+    "Recipient" : "Vastaanottaja",
     "Delete filter" : "Poista suodatin",
     "Operator" : "Operaattori",
+    "contains" : "sisältää",
+    "matches" : "täsmää",
     "Filter name" : "Nimisuodatin",
-    "Actions" : "Toiminnot",
-    "New action" : "Uusi toiminto",
     "Priority" : "Tärkeys",
     "Mail app" : "Sähköpostisovellus",
     "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
@@ -425,8 +420,6 @@ OC.L10N.register(
     "Anti Spam Service" : "Roskapostin estopalvelu",
     "Gmail integration" : "Gmail-integraatio",
     "Microsoft integration" : "Microsoft-integraatio",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft sallii käyttäjien yhdistää sähköpostiin IMAP:ia käyttäen. Tietoturvasyistä tällainen käyttö on mahdollista vain OAuth 2.0 -yhteydellä.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Rekisteröi uusi sovellus Microsoft Azure Active Directory -portaalissa. Lisää URL-osoite {url} uudelleenohjauksen URI:ksi.",
     "Anti Spam" : "Roskapostin esto",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Alkuperäinen viesti asetetaan \"message/rfc822\"-liitteeksi.",
     "Reset" : "Palauta",
@@ -499,6 +492,23 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
-    "Continue to %s" : "Jatka sivulle %s"
+    "Continue to %s" : "Jatka sivulle %s",
+    "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
+    "Draft: " : "Luonnos: ",
+    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
+    "Show only subscribed mailboxes" : "Näytä vain tilatut postilaatikot",
+    "Add mailbox" : "Lisää postilaatikko",
+    "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
+    "Show all mailboxes" : "Näytä kaikki postilaatikot",
+    "Clear mailbox" : "Tyhjennä postilaatikko",
+    "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
+    "Delete mailbox" : "Poista postilaatikko",
+    "Delete mailbox {name}" : "Poista postilaatikko {name}",
+    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
+    "Add submailbox" : "Lisää alipostilaatikko",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
+    "Actions" : "Toiminnot",
+    "New action" : "Uusi toiminto"
 },
 "nplurals=2; plural=(n != 1);");
