@@ -54,6 +54,7 @@ OC.L10N.register(
     "Email address" : "כתובת דוא״ל",
     "Add alias" : "הוספת כינוי",
     "Cancel" : "ביטול",
+    "Accounts" : "Accounts",
     "Add mail account" : "הוספת חשבון דוא״ל",
     "General" : "כללי",
     "Sorting" : "מיון",
@@ -100,12 +101,10 @@ OC.L10N.register(
     "Confirm" : "אימות",
     "Plain text" : "טקסט פשוט",
     "Rich text" : "טקסט עשיר",
-    "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
+    "No messages in this folder" : "אין הודעות בתיקייה זו",
     "No messages" : "אין הודעות",
     "Blind copy recipients only" : "נמענים נסתרים בלבד",
-    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
     "Could not delete message" : "לא ניתן למחוק הודעה",
-    "Draft: " : "טיוטה:",
     "Unfavorite" : "ביטול כמועדף",
     "Favorite" : "סימון כמועדף",
     "Read" : "קריאה",
@@ -134,8 +133,7 @@ OC.L10N.register(
     "Remove" : "הסרה",
     "email" : "דוא״ל",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
-    "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
+    "Choose target folder" : "נא לבחור תיקיית יעד",
     "Important info" : "מידע חשוב",
     "Other" : "אחר",
     "Forward" : "העברה",
@@ -153,25 +151,24 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
     "Message frame" : "מסגרת הודעה",
     "Move" : "העברה",
-    "Loading …" : "בטעינה",
-    "Not supported by the server" : "לא נתמך על ידי השרת",
     "Remove account" : "הסרת חשבון",
     "Remove {email}" : "להסיר את {email}",
-    "Quota" : "מכיסה",
-    "Add mailbox" : "הוספת תיבת דוא״ל",
+    "Show only subscribed folders" : "להציג תיקיות שבמינוי בלבד",
+    "Add folder" : "הוספת תיקייה",
+    "Folder name" : "שם התיקייה",
     "Saving" : "שמירה",
     "Move down" : "להוריד למטה",
-    "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
+    "Show all subscribed folders" : "להציג את כל התיקיות שבמינוי",
+    "Show all folders" : "הצגת כל התיקיות",
     "Collapse mailboxes" : "צמצום תיבות דוא״ל",
     "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
-    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
-    "Delete mailbox" : "מחיקת תיבת דוא״ל",
-    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
+    "Loading …" : "בטעינה",
+    "Delete folder" : "מחק תיקייה",
     "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
     "Mark all as read" : "סימון הכול כנקרא",
-    "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
-    "Add submailbox" : "הוספת תת־תיבת דוא״ל",
+    "Mark all messages of this folder as read" : "סימון כל ההודעות בתיקייה הזאת כנקראו",
+    "Add subfolder" : "הוספת תת־תיקייה",
     "Rename" : "שינוי שם",
     "Clear cache" : "פינוי מטמון",
     "Clear locally cached data, in case there are issues with synchronization." : "פינוי הנתונים שמאוחסנים מקומית במטמון, במקרה שיש תקלות בסנכרון.",
@@ -180,8 +177,6 @@ OC.L10N.register(
     "Reply" : "תגובה",
     "Error sending your message" : "שליחת ההודעה שלך נכשלה",
     "Retry" : "ניסיון חוזר",
-    "Uploading attachments …" : "הקבצים המצורפים מועלים…",
-    "Sending …" : "שולח...",
     "Message" : "הודעה",
     "Oh Snap!" : "שוד ושבר!",
     "Copy to clipboard" : "העתקה ללוח הגזירים",
@@ -197,6 +192,7 @@ OC.L10N.register(
     "Custom" : "מותאם אישית",
     "Signature …" : "חתימה…",
     "Save signature" : "שמירת החתימה",
+    "Message source" : "מקור ההודעה",
     "Tag already exists" : "תגית כבר קיימת",
     "An error occurred, unable to create the tag." : "אירעה שגיאה, לא ניתן ליצור את התגית.",
     "Add tag" : "הוספת תגית",
@@ -206,7 +202,6 @@ OC.L10N.register(
     "Reply to sender only" : "להגיב לשולח בלבד",
     "Mark as unread" : "סימון כלא נקרא",
     "Mark as read" : "סימון כנקרא",
-    "Message source" : "מקור ההודעה",
     "Could not remove trusted sender {sender}" : "לא ניתן להסיר את השולח המאומת {sender}",
     "No senders are trusted at the moment." : "אין שולחים מהימנים כרגע.",
     "Untitled event" : "אירוע ללא כותרת",
@@ -219,7 +214,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} מ־{depStation} אל {arrStation}",
     "Train from {depStation} to {arrStation}" : "רכבת מ־{depStation} אל {arrStation}",
     "Train" : "רכבת",
-    "Actions" : "פעולות",
+    "matches" : "תואם",
     "Priority" : "עדיפות",
     "Mail app" : "יישומון דוא״ל",
     "The mail app allows users to read mails on their IMAP accounts." : "יישומון הדוא״ל מאפשר למשתמשים לקרוא הודעות דוא״ל בחשבונות ה־IMAP שלהם.",
@@ -268,6 +263,19 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
     "Redirect" : "הפנייה",
     "The link leads to %s" : "הקישור מוביל אל %s",
-    "Continue to %s" : "ממשיך אל %s"
+    "Continue to %s" : "ממשיך אל %s",
+    "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
+    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
+    "Draft: " : "טיוטה:",
+    "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
+    "Add mailbox" : "הוספת תיבת דוא״ל",
+    "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
+    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
+    "Delete mailbox" : "מחיקת תיבת דוא״ל",
+    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
+    "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
+    "Add submailbox" : "הוספת תת־תיבת דוא״ל",
+    "Actions" : "פעולות"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
