@@ -103,17 +103,16 @@ OC.L10N.register(
     "Encrypt message with Mailvelope" : "Šifriraj poruku s Mailvelope",
     "Enter a date" : "Unesi datum",
     "Choose" : "Odaberite",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Privitak prekoračuje dopuštenu veličinu privitaka od {size}. Dijelite datoteku putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice."],
     "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
     "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
     "Confirm" : "Potvrdi",
     "Plain text" : "Običan tekst",
     "Rich text" : "Bogat tekst",
-    "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
+    "No messages in this folder" : "Nema poruka u ovoj mapi",
     "No messages" : "Nema poruka",
     "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
-    "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
     "Could not delete message" : "Brisanje poruke nije uspjelo",
-    "Draft: " : "Skica: ",
     "Unfavorite" : "Ukloni iz favorita",
     "Favorite" : "Favorit",
     "Read" : "Čitaj",
@@ -122,6 +121,7 @@ OC.L10N.register(
     "Edit tags" : "Uredi oznake",
     "Move thread" : "Premjesti dretvu",
     "Delete thread" : "Izbriši dretvu",
+    "Delete message" : "Izbriši poruku",
     "More actions" : "Dodatne radnje",
     "Back" : "Natrag",
     "Edit as new message" : "Uredi kao novu poruku",
@@ -153,9 +153,7 @@ OC.L10N.register(
     "Remove" : "Ukloni",
     "email" : "e-pošta",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
-    "Could not open mailbox" : "Nije moguće otvoriti sandučić",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
-    "Choose target mailbox" : "Odaberi ciljni sandučić",
+    "Choose target folder" : "Odaberi ciljnu mapu",
     "No more submailboxes in here" : "Ovdje više nema podsandučića",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
     "Important info" : "Važne informacije",
@@ -191,43 +189,39 @@ OC.L10N.register(
     "Moving" : "Premještanje",
     "Moving thread" : "Premještanje dretve",
     "Moving message" : "Premještanje poruke",
-    "Loading …" : "Učitavanje…",
-    "Not supported by the server" : "Ne podržava poslužitelj",
-    "{usage} of {limit} used" : "{usage} od {limit} iskorišteno",
     "Remove account" : "Izbriši račun",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} i podaci e-pošte spremljeni u predmemoriji uklonit će se iz Nextclouda, ali ne iz vašeg davatelja usluga e-pošte.",
     "Remove {email}" : "Ukloni {email}",
-    "Quota" : "Kvota",
-    "Show only subscribed mailboxes" : "Prikaži samo pretplaćene sandučiće",
-    "Add mailbox" : "Dodaj sandučić",
+    "Show only subscribed folders" : "Prikaži samo pretplaćene mape",
+    "Add folder" : "Dodaj mapu",
+    "Folder name" : "Naziv mape",
     "Saving" : "Spremanje",
     "Move up" : "Premjesti gore",
     "Move down" : "Premjesti dolje",
-    "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
-    "Show all mailboxes" : "Prikaži sve sandučiće",
+    "Show all subscribed folders" : "Prikaži sve pretplaćene mape",
+    "Show all folders" : "Prikaži sve mape",
     "Collapse mailboxes" : "Sakrij sandučiće",
     "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
-    "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
-    "Delete mailbox" : "Izbriši sandučić",
-    "Delete mailbox {name}" : "Izbriši sandučić {name}",
+    "Loading …" : "Učitavanje…",
+    "The folder and all messages in it will be deleted." : "Izbrisat će se mapa i sve poruke.",
+    "Delete folder" : "Izbriši mapu",
+    "Delete folder {name}" : "Izbriši mapu {name}",
     "An error occurred, unable to rename the mailbox." : "Došlo je do pogreške, nije moguće promijeniti naziv sandučića.",
     "Mark all as read" : "Označi sve kao pročitano",
-    "Mark all messages of this mailbox as read" : "Označi sve poruke u ovom sandučiću kao pročitane",
-    "Add submailbox" : "Dodaj podsandučić",
+    "Mark all messages of this folder as read" : "Označi sve poruke u ovoj mapi kao pročitane",
+    "Add subfolder" : "Dodaj podmapu",
     "Rename" : "Preimenuj",
+    "Move folder" : "Premjesti mapu",
     "Clear cache" : "Izbriši predmemoriju",
     "Clear locally cached data, in case there are issues with synchronization." : "Izbrišite podatke iz lokalnog međuspremnika u slučaju da postoje problemi sa sinkronizacijom.",
     "Subscribed" : "Pretplaćen",
     "Sync in background" : "Sinkronizacija u pozadini",
     "New message" : "Nova poruka",
     "Reply" : "Odgovori",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
     "Error sending your message" : "Pogreška pri slanju poruke",
     "Retry" : "Pokušaj ponovno",
-    "Uploading attachments …" : "Otpremanje privitaka...",
-    "Sending …" : "Slanje…",
     "Warning sending your message" : "Upozorenje pri slanju poruke",
     "Send anyway" : "Svejedno pošalji",
     "Message" : "Poruka",
@@ -255,6 +249,7 @@ OC.L10N.register(
     "Signature …" : "Potpis...",
     "Save signature" : "Spremi potpis",
     "Place signature above quoted text" : "Stavi potpis iznad citiranog teksta",
+    "Message source" : "Izvor poruke",
     "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
     "Saving new tag name …" : "Spremanje novog naziva oznake…",
     "Delete tag" : "Izbriši oznaku",
@@ -269,8 +264,6 @@ OC.L10N.register(
     "Reply to sender only" : "Odgovori pošiljatelju",
     "Mark as unread" : "Označi kao nepročitano",
     "Mark as read" : "Označi kao pročitano",
-    "Delete message" : "Izbriši poruku",
-    "Message source" : "Izvor poruke",
     "Could not remove trusted sender {sender}" : "Nije moguće ukloniti pouzdanog pošiljatelja {sender}",
     "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
     "Untitled event" : "Događaj bez naslova",
@@ -283,7 +276,8 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} do {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} do {arrStation}",
     "Train" : "Vlak",
-    "Actions" : "Radnje",
+    "Recipient" : "Primatelj",
+    "matches" : "podudara se",
     "Priority" : "Prioritet",
     "Successfully updated config for \"{domain}\"" : "Konfiguracija za „{domain}“ je uspješno ažurirana",
     "Error saving config" : "Pogreška pri spremanju konfiguracije",
@@ -333,7 +327,7 @@ OC.L10N.register(
     "Provisioning domain" : "Dodjeljivanje domene",
     "Email address template" : "Predložak adrese e-pošte",
     "IMAP" : "IMAP",
-    "User" : "Korisnik",
+    "User" : "@string/user_icon",
     "Host" : "Glavno računalo",
     "Port" : "Port",
     "SMTP" : "SMTP",
@@ -379,6 +373,23 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Kliknite ovdje ako niste preusmjereni automatski unutar sljedećih nekoliko sekundi.",
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
-    "Continue to %s" : "Idi do %s"
+    "Continue to %s" : "Idi do %s",
+    "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
+    "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
+    "Draft: " : "Skica: ",
+    "Could not open mailbox" : "Nije moguće otvoriti sandučić",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
+    "Choose target mailbox" : "Odaberi ciljni sandučić",
+    "Show only subscribed mailboxes" : "Prikaži samo pretplaćene sandučiće",
+    "Add mailbox" : "Dodaj sandučić",
+    "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
+    "Show all mailboxes" : "Prikaži sve sandučiće",
+    "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
+    "Delete mailbox" : "Izbriši sandučić",
+    "Delete mailbox {name}" : "Izbriši sandučić {name}",
+    "Mark all messages of this mailbox as read" : "Označi sve poruke u ovom sandučiću kao pročitane",
+    "Add submailbox" : "Dodaj podsandučić",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
+    "Actions" : "Radnje"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
