@@ -17,6 +17,7 @@ OC.L10N.register(
     "SMTP Password" : "Contrasigno SMTP",
     "Go back" : "Retornar",
     "Cancel" : "Cancellar",
+    "Accounts" : "Accounts",
     "General" : "General",
     "Keyboard shortcuts" : "Combinationes de claves",
     "Delete" : "Deler",
@@ -38,17 +39,17 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Selectiona un dossier pro salveguardar le attachamento",
     "Move" : "Mover",
     "Remove account" : "Remover conto",
-    "Quota" : "Quota",
+    "Folder name" : "Nomine de dossier",
     "Saving" : "Salveguardante",
+    "Show all folders" : "Monstrar tote dossiers",
     "Rename" : "Renominar",
     "Reply" : "Responder",
-    "Sending …" : "Inviante ...",
     "Add" : "Adder",
     "Close" : "Clauder",
     "Date" : "Date",
     "Tags" : "Etiquettas",
     "Custom" : "Personalisate",
-    "Actions" : "Actiones",
+    "matches" : "corresponde",
     "Priority" : "Prioritate",
     "Reset" : "Re-fixar",
     "User" : "User",
@@ -59,6 +60,7 @@ OC.L10N.register(
     "Favorites" : "Favoritos",
     "All inboxes" : "Tote cassas de entrata",
     "Could not load {tag}{name}{endtag}" : "Impossibile cargar {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}"
+    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}",
+    "Actions" : "Actiones"
 },
 "nplurals=2; plural=(n != 1);");
