@@ -5,13 +5,14 @@ OC.L10N.register(
     "Work" : "Arbeid",
     "Personal" : "Personleg",
     "Mail" : "Post",
+    "Save" : "Lagre",
+    "Connect" : "Kopla til",
     "Name" : "Namn",
     "Password" : "Passord",
     "None" : "Ingen",
-    "Save" : "Lagre",
-    "Connect" : "Kopla til",
     "Signature" : "Signatur",
     "Cancel" : "Avbryt",
+    "Accounts" : "Accounts",
     "General" : "Generelt",
     "Keyboard shortcuts" : "Tastatursnarvegar",
     "Delete" : "Ta bort",
@@ -20,24 +21,25 @@ OC.L10N.register(
     "Refresh" : "Last inn på nytt",
     "Choose" : "Vel",
     "Favorite" : "Favoritt",
-    "Select" : "Vel",
     "Back" : "Tilbake",
     "Description" : "Skildring",
     "Create" : "Lag",
+    "Select" : "Vel",
     "Comment" : "Kommentér",
     "Remove" : "Fjern",
     "Other" : "Anna",
     "Move" : "Move",
-    "Quota" : "Kvote",
+    "Folder name" : "Katalognavn",
     "Saving" : "Lagrar",
     "Rename" : "Endra namn",
-    "Retry" : "Forsøk att",
     "Reply" : "Svare",
+    "Retry" : "Forsøk att",
     "Add" : "Legg til",
     "Close" : "Lat att",
     "Date" : "Dato",
     "Tags" : "Emneord",
-    "Actions" : "Handlingar",
+    "Recipient" : "Mottakar",
+    "contains" : "inneheld",
     "Client ID" : "Klient-ID",
     "User" : "Bruker",
     "Host" : "Tenar",
@@ -46,6 +48,7 @@ OC.L10N.register(
     "All" : "Alle",
     "Favorites" : "Favorit",
     "Sent" : "Sendt",
-    "Message sent" : "Melding sendt"
+    "Message sent" : "Melding sendt",
+    "Actions" : "Handlingar"
 },
 "nplurals=2; plural=(n != 1);");
