@@ -9,6 +9,10 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Mail" : "Mail",
     "Mails" : "Mails",
+    "Connecting" : "Connexion",
+    "Save" : "Salvar",
+    "Connect" : "Connectar",
+    "Password required" : "Senhal requerit",
     "Name" : "Nom",
     "Password" : "Senhal",
     "IMAP Settings" : "Paramètres IMAP",
@@ -18,10 +22,6 @@ OC.L10N.register(
     "IMAP Password" : "Senhal IMAP",
     "SMTP Settings" : "Paramètres SMTP",
     "SMTP Password" : "Senhal SMTP",
-    "Connecting" : "Connexion",
-    "Save" : "Salvar",
-    "Connect" : "Connectar",
-    "Password required" : "Senhal requerit",
     "Account settings" : "Paramètres de compte",
     "Signature" : "Signatura",
     "Mail server" : "Servidor email",
@@ -29,9 +29,11 @@ OC.L10N.register(
     "Go back" : "Revenir en arrière",
     "Email address" : "Adreça mail",
     "Cancel" : "Anullar",
+    "Accounts" : "Accounts",
     "General" : "Generals",
     "List" : "Tièra",
     "Register" : "S'inscriure",
+    "About" : "A prepaus",
     "Keyboard shortcuts" : "Acorchis de clavièr",
     "Archive" : "Archius",
     "Delete" : "Suprimir",
@@ -41,10 +43,11 @@ OC.L10N.register(
     "From" : "De",
     "Write message …" : "Escriure un messatge…",
     "Monday morning" : "Diluns matin",
-    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
     "Choose" : "Causir",
+    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
     "Confirm" : "Confirmar",
     "No messages" : "Cap de messatge",
+    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Favorite" : "Favorit",
     "Read" : "Legit",
     "More actions" : "Mai d’accions",
@@ -61,22 +64,22 @@ OC.L10N.register(
     "Translate" : "Tradurre",
     "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
     "Move" : "Move",
-    "Quota" : "Quota",
+    "Folder name" : "Nom del dorsièr",
+    "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
     "Loading …" : "Cargament…",
+    "Delete folder" : "Suprimir dossièr",
     "Mark all as read" : "Marcar totes coma legits",
     "Rename" : "Tornar nommar",
     "Clear cache" : "Voidar l'escondedor",
-    "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
-    "Retry" : "Tornar ensajar",
-    "Sending …" : "Mandadís…",
     "Reply" : "Respondre",
+    "Retry" : "Tornar ensajar",
     "Copy to clipboard" : "Copiar dins lo quichapapièrs",
     "Add" : "Apondre",
+    "Clear" : "Escafar",
     "Close" : "Tampar",
     "Body" : "Còs",
     "Date" : "Data",
     "Tags" : "Etiquetas",
-    "Clear" : "Escafar",
     "Custom" : "Personalizats",
     "Mark as unread" : "Marcar coma pas legit",
     "Mark as read" : "Marcar coma legit",
@@ -85,17 +88,15 @@ OC.L10N.register(
     "Untitled event" : "Eveniment sens títol",
     "Train" : "Tren",
     "Flag" : "Drapèu",
-    "Actions" : "Accions",
     "Reset" : "Reïnicializar",
     "Client ID" : "ID client",
-    "User" : "User",
+    "User" : "Utilizator",
     "Host" : "Òste",
     "Port" : "Pòrt",
     "Valid until" : "Valid fins a",
     "Certificate" : "Certificat",
     "Submit" : "Transmetre",
     "Account connected" : "Compte connectat",
-    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "All" : "Tot",
     "Drafts" : "Borrolhons",
     "Favorites" : "Favorits",
@@ -108,6 +109,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "Message sent" : "Messatge mandat",
     "Error loading message" : "Error al moment del cargament del messatge",
-    "Continue to %s" : "Contunhar cap a %s"
+    "Continue to %s" : "Contunhar cap a %s",
+    "Actions" : "Accions"
 },
 "nplurals=2; plural=(n > 1);");
