@@ -66,6 +66,7 @@ OC.L10N.register(
     "Cancel" : "Avbryt",
     "Put my text to the bottom of a reply instead of on top of it." : "Infoga min text längst ner i ett svar i stället för längst upp.",
     "Could not update preference" : "Kunde inte uppdatera inställningar",
+    "Mail settings" : "E-postinställningar",
     "Accounts" : "Konton",
     "Add mail account" : "Lägg till e-postkonto",
     "General" : "Allmänt",
@@ -79,6 +80,7 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
     "Trusted senders" : "Betrodda avsändare",
     "Looking for a way to encrypt your emails?" : "Söker du efter ett sätt att kryptera meddelanden?",
+    "Install Mailvelope browser extension" : "Installera webbläsartillägget Mailvelope",
     "About" : "Om",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Compose new message" : "Skapa nytt meddelande",
@@ -128,7 +130,7 @@ OC.L10N.register(
     "Confirm" : "Bekräfta",
     "Plain text" : "Oformaterad text",
     "Rich text" : "Formaterad text",
-    "No messages in this mailbox" : "Inga meddelanden i den här brevlådan",
+    "No messages in this folder" : "Inga meddelanden i denna mapp",
     "No messages" : "Inga meddelanden",
     "Blind copy recipients only" : "Endast mottagare för blindkopior",
     "No subject" : "Ingen ämnesrad",
@@ -140,10 +142,8 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
     "Next week – {timeLocale}" : "Nästa vecka – {timeLocale}",
     "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
-    "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
     "Could not delete message" : "Kunde inte radera meddelande",
     "Could not archive message" : "Kunde inte arkivera meddelandet",
-    "Draft: " : "Utkast:",
     "Unfavorite" : "Inte favorit",
     "Favorite" : "Favorit",
     "Unread" : "Oläst",
@@ -154,7 +154,9 @@ OC.L10N.register(
     "Edit tags" : "Redigera taggar",
     "Move thread" : "Flytta tråd",
     "Archive thread" : "Arkivera tråd",
+    "Archive message" : "Arkivera meddelandet",
     "Delete thread" : "Radera tråd",
+    "Delete message" : "Radera meddelande",
     "More actions" : "Fler händelser",
     "Back" : "Tillbaka",
     "Edit as new message" : "Redigera som nytt meddelande",
@@ -184,10 +186,8 @@ OC.L10N.register(
     "Remove" : "Ta bort",
     "email" : "e-post",
     "Itinerary for {type} is not supported yet" : "Resplan för {type} stöds inte än",
-    "Could not open mailbox" : "Kunde inte öppna brevlådan",
     "Loading messages …" : "Läser in meddelanden …",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexera dina meddelanden. Det kan ta lite längre tid för större brevlådor.",
-    "Choose target mailbox" : "Välj markerad inkorg",
+    "Choose target folder" : "Välj målmapp",
     "No more submailboxes in here" : "Inga fler undermappar här",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
     "Important info" : "Viktig info",
@@ -221,27 +221,29 @@ OC.L10N.register(
     "Moving" : "Flyttar",
     "Moving thread" : "Flyttar tråd",
     "Moving message" : "Flyttar meddelande",
-    "Loading …" : "Läser in ...",
-    "Not supported by the server" : "Stöds ej av  servern",
-    "{usage} of {limit} used" : "{usage} av {limit} använt",
     "Remove account" : "Ta bort konto",
     "Remove {email}" : "Ta bort {email}",
-    "Quota" : "Kvot",
-    "Show only subscribed mailboxes" : "Visa endast prenumererade brevlådor",
-    "Add mailbox" : "Lägg till brevlåda",
+    "Show only subscribed folders" : "Visa endast mappar som du prenumererar på",
+    "Add folder" : "Lägg till mapp",
+    "Folder name" : "Mappnamn",
     "Saving" : "Sparar",
     "Move up" : "Flytta upp",
     "Move down" : "Flytta ner",
-    "Show all subscribed mailboxes" : "Visa alla prenumererade brevlådor",
-    "Show all mailboxes" : "Visa alla brevlådor",
+    "Show all subscribed folders" : "Visa alla mappar som du prenumererar på",
+    "Show all folders" : "Visa alla kataloger",
     "Collapse mailboxes" : "Minimera brevlådor",
     "_{total} message_::_{total} messages_" : ["{total} meddelande","{total} meddelanden"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} av {total} oläst","{unread} av {total} oläst"],
-    "Delete mailbox" : "Radera brevlåda",
+    "Loading …" : "Läser in ...",
+    "The folder and all messages in it will be deleted." : "Denna mapp och alla meddelanden i den kommer att raderas.",
+    "Delete folder" : "Radera mapp",
+    "Delete folder {name}" : "Ta bort mapp {name}",
     "An error occurred, unable to rename the mailbox." : "Ett fel inträffade, det gick inte att byta namn på brevlådan.",
     "Mark all as read" : "Markera alla som lästa",
-    "Mark all messages of this mailbox as read" : "Markera alla meddelanden i den här brevlådan som lästa",
+    "Mark all messages of this folder as read" : "Markera alla meddelanden i den här mappen som lästa",
+    "Add subfolder" : "Skapa undermapp",
     "Rename" : "Byt namn",
+    "Move folder" : "Flytta mapp",
     "Clear cache" : "Rensa cachen",
     "Clear locally cached data, in case there are issues with synchronization." : "Rensa lokalt cachad data, ifall det finns problem med synkronisering.",
     "Subscribed" : "Prenumeration aktiverad",
@@ -253,8 +255,6 @@ OC.L10N.register(
     "Reply" : "Svara",
     "Error sending your message" : "Ett fel inträffade när ditt meddelande skulle skickas",
     "Retry" : "Försök igen",
-    "Uploading attachments …" : "Laddar upp bilagor ...",
-    "Sending …" : "Skickar ...",
     "Send anyway" : "Skicka ändå",
     "First day" : "Första dagen",
     "Message" : "Meddelande",
@@ -269,7 +269,6 @@ OC.L10N.register(
     "Show less" : "Visa mindre",
     "Show more" : "Visa mer",
     "Clear" : "Rensa",
-    "Search in mailbox" : "Sök i brevlådan",
     "Close" : "Stäng",
     "Search parameters" : "Sökparametrar",
     "Body" : "Textyta",
@@ -283,6 +282,7 @@ OC.L10N.register(
     "Signature …" : "Signatur …",
     "Save signature" : "Spara signatur",
     "Place signature above quoted text" : "Placera signaturen ovanför citerad text",
+    "Message source" : "Meddelandekälla",
     "An error occurred, unable to rename the tag." : "Ett fel uppstod, kunde inte byta taggens namn.",
     "Delete tag" : "Radera tagg",
     "Tag already exists" : "Taggen finns redan",
@@ -297,9 +297,6 @@ OC.L10N.register(
     "Reply to sender only" : "Svara endast avsändaren",
     "Mark as unread" : "Markera som oläst",
     "Mark as read" : "Markera som läst",
-    "Archive message" : "Arkivera meddelandet",
-    "Delete message" : "Radera meddelande",
-    "Message source" : "Meddelandekälla",
     "The message could not be translated" : "Meddelandet kunde inte översättas",
     "Translation copied to clipboard" : "Översättningen har kopierats till urklipp",
     "Translation could not be copied" : "Översättningen kunde inte kopieras",
@@ -321,17 +318,20 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} från {depStation} till {arrStation}",
     "Train from {depStation} to {arrStation}" : "Tåg från {depStation} till {arrStation}",
     "Train" : "Tåg",
+    "Flag" : "Flag",
+    "Recipient" : "Mottagare",
     "Delete filter" : "Ta bort filter",
     "Operator" : "Operatör",
+    "contains" : "innehåller",
+    "matches" : "träffar",
     "Filter name" : "Filternamn",
-    "Actions" : "Funktioner",
-    "New action" : "Ny åtgärd",
     "Priority" : "Prioritet",
     "Mail app" : "Mail-app",
     "The mail app allows users to read mails on their IMAP accounts." : "Mail-appen tillåter användare att läsa e-post på sina IMAP-konton.",
     "Reset" : "Återställ",
     "Client ID" : "Klient-ID",
     "Client secret" : "Klienthemlighet",
+    "Unlink" : "Unlink",
     "Email: {email}" : "E-post: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} på {host}:{port} ({ssl}-krypterat)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} på {host}:{port} ({ssl}-krypterat)",
@@ -376,6 +376,21 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
-    "Continue to %s" : "Fortsätt till %s"
+    "Continue to %s" : "Fortsätt till %s",
+    "No messages in this mailbox" : "Inga meddelanden i den här brevlådan",
+    "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
+    "Draft: " : "Utkast:",
+    "Could not open mailbox" : "Kunde inte öppna brevlådan",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexera dina meddelanden. Det kan ta lite längre tid för större brevlådor.",
+    "Choose target mailbox" : "Välj markerad inkorg",
+    "Show only subscribed mailboxes" : "Visa endast prenumererade brevlådor",
+    "Add mailbox" : "Lägg till brevlåda",
+    "Show all subscribed mailboxes" : "Visa alla prenumererade brevlådor",
+    "Show all mailboxes" : "Visa alla brevlådor",
+    "Delete mailbox" : "Radera brevlåda",
+    "Mark all messages of this mailbox as read" : "Markera alla meddelanden i den här brevlådan som lästa",
+    "Search in mailbox" : "Sök i brevlådan",
+    "Actions" : "Funktioner",
+    "New action" : "Ny åtgärd"
 },
 "nplurals=2; plural=(n != 1);");
