@@ -5,15 +5,15 @@ OC.L10N.register(
     "Work" : "ที่ทำงาน",
     "Personal" : "ส่วนตัว",
     "Mail" : "จดหมาย",
+    "Connecting" : "กำลังเชื่อมต่อ",
+    "Save" : "บันทึก",
+    "Connect" : "เชื่อมต่อ",
     "Name" : "ชื่อ",
     "Password" : "รหัสผ่าน",
     "None" : "ไม่มี",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "SMTP Password" : "รหัสผ่าน SMTP",
-    "Connecting" : "กำลังเชื่อมต่อ",
-    "Save" : "บันทึก",
-    "Connect" : "เชื่อมต่อ",
     "Signature" : "ลายเซ็น",
     "Go back" : "กลับไป",
     "Change name" : "เปลี่ยนชื่อ",
@@ -22,14 +22,15 @@ OC.L10N.register(
     "Accounts" : "บัญชี",
     "General" : "ทั่วไป",
     "Register" : "ลงทะเบียน",
+    "About" : "เกี่ยวกับ",
     "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "Archive" : "ที่เก็บถาวร",
     "Delete" : "ลบ",
     "Search" : "ค้นหา",
     "Send" : "ส่ง",
     "Refresh" : "รีเฟรช",
-    "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
     "Choose" : "เลือก",
+    "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
     "Confirm" : "ยืนยัน",
     "Favorite" : "รายการโปรด",
     "Read" : "อ่าน",
@@ -42,34 +43,34 @@ OC.L10N.register(
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
     "Remove" : "ลบออก",
+    "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
     "Other" : "อื่น ๆ",
     "Forward" : "ส่งต่อ",
     "Translate" : "แปลภาษา",
-    "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บไฟล์แนบลงไป",
     "Unnamed" : "ไม่มีชื่อ",
+    "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บไฟล์แนบลงไป",
     "Move" : "ย้าย",
     "Moving" : "กำลังย้าย",
-    "Quota" : "โควต้า",
-    "Saving" : "กำลังบันทึก",
     "Remove account" : "ลบบัญชี",
+    "Folder name" : "ชื่อโฟลเดอร์",
+    "Saving" : "กำลังบันทึก",
+    "Show all folders" : "แสดงโฟลเดอร์ทั้งหมด",
     "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
     "Rename" : "เปลี่ยนชื่อ",
     "Clear cache" : "ล้างแคช",
-    "Sending …" : "กำลังส่ง ...",
     "Reply" : "ตอบกลับ",
     "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
     "Add" : "เพิ่ม",
+    "Clear" : "ล้าง",
     "Close" : "ปิด",
     "Date" : "วันที่",
     "Tags" : "แท็ก",
     "Last 7 days" : "ภายใน 7 วัน",
-    "Clear" : "ล้าง",
     "Custom" : "กำหนดเอง",
     "Tag already exists" : "มีแท็กอยู่แล้ว",
     "Not found" : "ไม่พบ",
-    "Actions" : "การกระทำ",
     "Priority" : "ลำดับความสำคัญ",
-    "Reset" : "ตั้งค่าใหม่",
+    "Reset" : "รีเซ็ต",
     "Client ID" : "รหัสไคลเอ็นต์",
     "Client secret" : "ข้อมูลลับไคลเอ็นต์",
     "User" : "ผู้ใช้",
@@ -92,6 +93,6 @@ OC.L10N.register(
     "Redirect" : "เปลี่ยนเส้นทาง",
     "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
     "Continue to %s" : "ดำเนินการต่อไปที่ %s",
-    "Unselect" : "ยกเลิกการเลือก"
+    "Actions" : "การกระทำ"
 },
 "nplurals=1; plural=0;");
