@@ -1,7 +1,9 @@
 OC.L10N.register(
     "mail",
     {
+    "Work" : "Ish",
     "Personal" : "Personal",
+    "Later" : "Keyinchalik",
     "Mail" : "Mail",
     "Save" : "Save",
     "Connect" : "Connect",
@@ -13,7 +15,9 @@ OC.L10N.register(
     "Accounts" : "Akkaunt",
     "General" : "General",
     "List" : "Ro`yxat",
+    "Register" : "Roʻyxatdan oʻtish",
     "About" : "About",
+    "Archive" : "Arxiv",
     "Delete" : "Delete",
     "Search" : "Search",
     "Send" : "Send",
@@ -33,6 +37,7 @@ OC.L10N.register(
     "Description" : "Tavsif",
     "Create" : "Yaratish",
     "Select" : "Select",
+    "Comment" : "Izoh",
     "Accept" : "Qabul qiling",
     "Decline" : "Rad etish",
     "More options" : "Boshqa variantlar",
@@ -41,8 +46,10 @@ OC.L10N.register(
     "Other" : "Boshqa",
     "Translate" : "Tarjima",
     "Move" : "Move",
-    "Quota" : "kvota",
+    "Remove {email}" : " {email} ni o'chirish",
+    "Folder name" : "Jild nomi",
     "Saving" : "Saving",
+    "Delete folder" : "Jildni o'chirish",
     "Rename" : "Nomini o'zgartirish",
     "Subscribed" : "Obuna boʻlgan",
     "Reply" : "Javob bering",
@@ -52,16 +59,20 @@ OC.L10N.register(
     "Tags" : "Tags",
     "Last 7 days" : "Oxirgi 7 kun",
     "Custom" : "Boshqa",
+    "Add tag" : "Teg qo'shing",
     "Not found" : "Topilmadi",
     "Untitled event" : "Nomsiz tadbir",
     "(organizer)" : "(tashkilotchi)",
     "Operator" : "Operator",
-    "Actions" : "Actions",
+    "contains" : "o'z ichiga oladi",
+    "Reset" : "Qayta tiklash",
+    "Client ID" : "Mijoz identifikatori",
     "Port" : "Port",
     "Account connected" : "Akkaunt ulangan",
     "All" : "All",
     "Favorites" : "Favorites",
     "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
-    "Continue to %s" : " %sni davom eting"
+    "Continue to %s" : " %sni davom eting",
+    "Actions" : "Faolliklar"
 },
 "nplurals=1; plural=0;");
