@@ -3,24 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright 2020 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @author 2020 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Listener;
@@ -34,6 +18,7 @@ use OCA\Mail\IMAP\Threading\ThreadBuilder;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
 use function array_chunk;
+use function gc_collect_cycles;
 use function iterator_to_array;
 
 /**
@@ -68,17 +53,21 @@ class AccountSynchronizedThreadUpdaterListener implements IEventListener {
 		$accountId = $event->getAccount()->getId();
 		$logger->debug("Building threads for account $accountId");
 		$messages = $this->mapper->findThreadingData($event->getAccount());
-		$logger->debug("Account $accountId has " . count($messages) . " messages with threading information");
+		$logger->debug("Account $accountId has " . count($messages) . ' messages with threading information');
 		$threads = $this->builder->build($messages, $logger);
-		$logger->debug("Account $accountId has " . count($threads) . " threads");
+		$logger->debug("Account $accountId has " . count($threads) . ' threads');
 		/** @var DatabaseMessage[] $flattened */
 		$flattened = iterator_to_array($this->flattenThreads($threads), false);
-		$logger->debug("Account $accountId has " . count($flattened) . " messages with a new thread IDs");
+		$logger->debug("Account $accountId has " . count($flattened) . ' messages with a new thread IDs');
 		foreach (array_chunk($flattened, self::WRITE_IDS_CHUNK_SIZE) as $chunk) {
 			$this->mapper->writeThreadIds($chunk);
 
-			$logger->debug("Chunk of " . self::WRITE_IDS_CHUNK_SIZE . " messages updated");
+			$logger->debug('Chunk of ' . self::WRITE_IDS_CHUNK_SIZE . ' messages updated');
 		}
+
+		// Free memory
+		unset($flattened, $threads, $messages);
+		gc_collect_cycles();
 	}
 
 	/**
